@@ -90,12 +90,14 @@ impl TryFrom<&HadolintResult> for sarif::Region {
   }
 }
 
-fn process<R: BufRead>(reader: R) -> Result<sarif::Sarif> {
+fn process<R: BufRead>(mut reader: R) -> Result<sarif::Sarif> {
+  let mut data = String::new();
+  reader.read_to_string(&mut data)?;
   let mut results = vec![];
   let mut map = HashMap::new();
   let mut rules = vec![];
 
-  let hadolint_results: Vec<HadolintResult> = serde_json::from_reader(reader)?;
+  let hadolint_results: Vec<HadolintResult> = serde_json::from_str(&data)?;
   hadolint_results
     .iter()
     .try_for_each(|result| -> Result<()> {
